jQuery(document).ready(function($) {
    'use strict';
    
    var $form = $('#category-merger-form');
    var $sourceSelect = $('#source-category');
    var $targetSelect = $('#target-category');
    var $mergeButton = $('#merge-button');
    var $resultDiv = $('#merge-result');
    
    // Form gönderimini yakala
    $form.on('submit', function(e) {
        e.preventDefault();
        
        var sourceCategory = $sourceSelect.val();
        var targetCategory = $targetSelect.val();
        
        // Validasyon kontrolleri
        if (!sourceCategory) {
            showMessage(wpCategoryMerger.messages.select_source, 'error');
            return;
        }
        
        if (!targetCategory) {
            showMessage(wpCategoryMerger.messages.select_target, 'error');
            return;
        }
        
        if (sourceCategory === targetCategory) {
            showMessage(wpCategoryMerger.messages.same_category, 'error');
            return;
        }
        
        // Kullanıcıdan onay al
        if (!confirm(wpCategoryMerger.messages.confirm_merge)) {
            return;
        }
        
        // Birleştirme işlemini başlat
        mergeCategories(sourceCategory, targetCategory);
    });
    
    // Kategori seçimi değiştiğinde diğer seçenekleri güncelle
    $sourceSelect.on('change', function() {
        updateTargetOptions();
    });
    
    $targetSelect.on('change', function() {
        updateSourceOptions();
    });
    
    function updateTargetOptions() {
        var selectedSource = $sourceSelect.val();
        
        $targetSelect.find('option').each(function() {
            var $option = $(this);
            var value = $option.val();
            
            if (value && value === selectedSource) {
                $option.prop('disabled', true).hide();
            } else {
                $option.prop('disabled', false).show();
            }
        });
        
        // Eğer hedef kategori kaynak kategori ile aynıysa temizle
        if ($targetSelect.val() === selectedSource) {
            $targetSelect.val('');
        }
    }
    
    function updateSourceOptions() {
        var selectedTarget = $targetSelect.val();
        
        $sourceSelect.find('option').each(function() {
            var $option = $(this);
            var value = $option.val();
            
            if (value && value === selectedTarget) {
                $option.prop('disabled', true).hide();
            } else {
                $option.prop('disabled', false).show();
            }
        });
        
        // Eğer kaynak kategori hedef kategori ile aynıysa temizle
        if ($sourceSelect.val() === selectedTarget) {
            $sourceSelect.val('');
        }
    }
    
    function mergeCategories(sourceCategory, targetCategory) {
        // UI'yi güncelle
        $mergeButton.prop('disabled', true);
        showMessage(wpCategoryMerger.messages.merging, 'info');
        
        // Spinner ekle
        if (!$mergeButton.find('.spinner').length) {
            $mergeButton.prepend('<span class="spinner is-active"></span>');
        }
        
        // AJAX isteği gönder
        $.ajax({
            url: wpCategoryMerger.ajax_url,
            type: 'POST',
            data: {
                action: 'merge_categories',
                source_category: sourceCategory,
                target_category: targetCategory,
                nonce: wpCategoryMerger.nonce
            },
            success: function(response) {
                if (response.success) {
                    showMessage(response.data, 'success');
                    
                    // Sayfayı yenile (kategoriler güncellensin)
                    setTimeout(function() {
                        location.reload();
                    }, 2000);
                } else {
                    showMessage(response.data || wpCategoryMerger.messages.error, 'error');
                }
            },
            error: function(xhr, status, error) {
                console.error('AJAX Error:', error);
                showMessage(wpCategoryMerger.messages.error + ' (' + error + ')', 'error');
            },
            complete: function() {
                // UI'yi eski haline getir
                $mergeButton.prop('disabled', false);
                $mergeButton.find('.spinner').remove();
            }
        });
    }
    
    function showMessage(message, type) {
        $resultDiv.removeClass('success error info')
                  .addClass(type)
                  .html('<p>' + message + '</p>')
                  .show();
        
        // Sayfayı mesaja kaydır
        $('html, body').animate({
            scrollTop: $resultDiv.offset().top - 100
        }, 500);
        
        // Hata mesajları için otomatik gizleme
        if (type === 'error') {
            setTimeout(function() {
                $resultDiv.fadeOut();
            }, 5000);
        }
    }
    
    // Sayfa yüklendiğinde seçenekleri güncelle
    updateTargetOptions();
    updateSourceOptions();
});

